@@ -62,6 +62,84 @@ static const char *pacUtils =
 "    \n"
 "}\n"
 
+"function convert_addr6(ipchars) {\n"
+"    ipchars = ipchars.replace(/(^:|:$)/, '');\n"
+"    var fields = ipchars.split(':');\n"
+"    var diff = 8 - fields.length;\n"
+"    for (var i = 0; i < fields.length; i++) {\n"
+"        if (fields[i] == '') {\n"
+"            fields[i] = '0';\n"
+"            // inject 'diff' number of '0' elements here.\n"
+"            for (var j = 0; j < diff; j++) {\n"
+"                fields.splice(i++, 0, '0');\n"
+"            }\n"
+"            break;\n"
+"        }\n"
+"    }\n"
+"    var result = [];\n"
+"    for (var i = 0; i < fields.length; i++) {\n"
+"        result.push(parseInt(fields[i], 16));\n"
+"    }\n"
+"    return result;\n"
+"}\n"
+
+"function isInNetEx6(ipaddr, prefix, prefix_len) {\n"
+"    if (prefix_len > 128) {\n"
+"        return false;\n"
+"    }\n"
+"    prefix = convert_addr6(prefix);\n"
+"    ip = convert_addr6(ipaddr);\n"
+"    // Prefix match strategy:\n"
+"    //   Compare only prefix length bits between 'ipaddr' and 'prefix'\n"
+"    //   Match in the batches of 16-bit fields \n"
+"    prefix_rem = prefix_len % 16;\n"
+"    prefix_nfields = (prefix_len - prefix_rem) / 16;\n"
+"\n"
+"    for (var i = 0; i < prefix_nfields; i++) {\n"
+"        if (ip[i] != prefix[i]) {\n"
+"            return false;\n"
+"        }\n"
+"    }\n"
+"    if (prefix_rem > 0) {\n"
+"        // Compare remaining bits\n"
+"        prefix_bits = prefix[prefix_nfields] >> (16 - prefix_rem);\n"
+"        ip_bits = ip[prefix_nfields] >> (16 - prefix_rem);\n"
+"        if (ip_bits != prefix_bits) {\n"
+"            return false;\n"
+"        }\n"
+"    }\n"
+"    return true;\n"
+"}\n"
+
+"function isInNetEx4(ipaddr, prefix, prefix_len) {\n"
+"    if (prefix_len > 32) {\n"
+"        return false;\n"
+"    }\n"
+"    var netmask = [];\n"
+"    for (var i = 1; i < 5; i++) {\n"
+"        var shift_len = 8 * i - prefix_len;\n"
+"        if (shift_len <= 0) {\n"
+"            netmask.push(255)\n"
+"        } else {\n"
+"            netmask.push((0xff >> shift_len) << shift_len);\n"
+"        }\n"
+"    }\n"
+"    return isInNet(ipaddr, prefix, netmask.join('.'));\n"
+"}\n"
+
+"function isInNetEx(ipaddr, prefix) {\n"
+"    prefix_a = prefix.split('/');\n"
+"    if (prefix_a.length != 2) {\n"
+"        return false;\n"
+"    }\n"
+"    var test = /^\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}$/.test(ipaddr);\n"
+"    if (!test) {\n"
+"        return isInNetEx6(ipaddr, prefix_a[0], prefix_a[1]);\n"
+"    } else {\n"
+"        return isInNetEx4(ipaddr, prefix_a[0], prefix_a[1]);\n"
+"    }\n"
+"}\n"
+
 "function isPlainHostName(host) {\n"
 "    return (host.search('\\\\.') == -1);\n"
 "}\n"
@@ -245,4 +323,50 @@ static const char *pacUtils =
 "        date.setSeconds(date.getUTCSeconds());\n"
 "    }\n"
 "    return ((date1 <= date) && (date <= date2));\n"
+"}\n"
+
+"function findProxyForURL(url, host) {\n"
+"    if (typeof FindProxyForURLEx == 'function') {\n"
+"        return FindProxyForURLEx(url, host);\n"
+"    } else {\n"
+"        return FindProxyForURL(url, host);\n"
+"    }\n"
 "}\n";
+
+
+// You must free the result if result is non-NULL.
+char *str_replace(const char *orig, char *rep, char *with) {
+    char *tmporig = malloc(strlen(orig) + 1); // Copy of orig that we work with
+    tmporig = strcpy(tmporig, orig);
+
+    char *result;  // the return string
+    char *ins;     // the next insert point
+    char *tmp;     // varies
+    int count;     // number of replacements
+    int len_front; // distance between rep and end of last rep
+    int len_rep  = strlen(rep);
+    int len_with = strlen(with);
+
+    // Get the count of replacements
+    ins = tmporig;
+    for (count = 0; (tmp = strstr(ins, rep)); ++count) {
+        ins = tmp + len_rep;
+    }
+
+    tmp = result = malloc(strlen(tmporig) + (len_with - len_rep) * count + 1);
+
+    // first time through the loop, all the variable are set correctly
+    // from here on,
+    //    tmp points to the end of the result string
+    //    ins points to the next occurrence of rep in tmporig
+    //    tmporig points to the remainder of tmporig after "end of rep"
+    while (count--) {
+        ins = strstr(tmporig, rep);
+        len_front = ins - tmporig;
+        tmp = strncpy(tmp, tmporig, len_front) + len_front;
+        tmp = strcpy(tmp, with) + len_with;
+        tmporig += len_front + len_rep; // move to next "end of rep"
+    }
+    strcpy(tmp, tmporig);
+    return result;
+}
